@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "modifyjob.h"
@@ -75,7 +75,7 @@ void ModifyJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNet
     // doesn't transfer the body correctly.
     // Using sendCustomRequest() works just fine.
     //accessManager->put(r, data);
-    if (data.size() > 0) {
+    if (!data.isEmpty()) {
         r.setHeader(QNetworkRequest::ContentLengthHeader, data.size());
 
         d->buffer.close();
